@@ -128,9 +128,12 @@ def _scale(surface, width, height):
             new_surf = pygame.transform.scale(surface, (width, height))
     elif sge.game.scale_method == "scale2x":
         new_surf = surface
-        while (width / new_surf.get_width() >= 2 and
-               height / new_surf.get_height() >= 2):
-            new_surf = pygame.transform.scale2x(new_surf)
+        while (width > new_surf.get_width() or
+               height > new_surf.get_height()):
+            try:
+                new_surf = pygame.transform.scale2x(new_surf)
+            except pygame.error:
+                break
 
         if new_surf.get_width() != width or new_surf.get_height() != height:
             new_surf = pygame.transform.scale(surface, (width, height))
@@ -213,8 +216,8 @@ def _set_mode():
         force_auto_scale = False
 
         if game.scale:
-            target_width = game.width * game.scale
-            target_height = game.height * game.scale
+            target_width = int(game.width * game.scale)
+            target_height = int(game.height * game.scale)
             if (target_width, target_height) in modes:
                 game_window_width = target_width
                 game_window_height = target_height
@@ -1022,13 +1025,17 @@ def s_set_size(self):
                 self.rd["baseimages"][i] = pygame.transform.scale(
                     self.rd["baseimages"][i], (width, height))
         elif sge.game.scale_method == "scale2x":
-            new_surf = surface
-            while (width / new_surf.get_width() >= 2 and
-                   height / new_surf.get_height() >= 2):
-                new_surf = pygame.transform.scale2x(new_surf)
+            new_surf = self.rd["baseimages"][i]
+            while (width > new_surf.get_width() or
+                   height > new_surf.get_height()):
+                try:
+                    new_surf = pygame.transform.scale2x(new_surf)
+                except pygame.error:
+                    break
 
             if new_surf.get_width() != width or new_surf.get_height() != height:
-                new_surf = pygame.transform.scale(surface, (width, height))
+                new_surf = pygame.transform.scale(self.rd["baseimages"][i],
+                                                  (width, height))
 
             self.rd["baseimages"][i] = new_surf
         else:
